
local SC = LibStub("AceAddon-3.0"):NewAddon("SpecChanger", "AceConsole-3.0", "AceEvent-3.0");
local SCLDB = LibStub("LibDataBroker-1.1"):NewDataObject("SCObj",  {
	type = "data source",
	text = "Spec Changer",
	icon = "Interface\\Icons\\Ability_dualwieldspecialization",
});

local icon = LibStub("LibDBIcon-1.0");

local SpecIcons = {};
SpecIcons["Warrior"] = { ["Arms"] = 132355, ["Fury"] = 132347, ["Protection"] = 132341 };
SpecIcons["Paladin"] = { ["Holy"] = 135920, ["Protection"] = 236264, ["Retribution"] = 535595 };
SpecIcons["Hunter"] = { ["Beast Mastery"] = 461112, ["Markmanship"] = 236179, ["Survival"] = 461113 };
SpecIcons["Rogue"] = { ["Assassination"] = 236270, ["Combat"] = 1140280, ["Subtlety"] = 132320 };
SpecIcons["Priest"] = { ["Discipline"] = 135940, ["Holy"] = 237542, ["Shadow"] = 136207 };
SpecIcons["DeathKnight"] = { ["Blood"] = 135770, ["Frost"] = 135773, ["Unholy"] = 135775 };
SpecIcons["Shaman"] = { ["Elemental"] = 136048,  ["Enhancement"] = 237581, ["Restoration"] = 136043 };
SpecIcons["Mage"] = { ["Arcane"] = 135869, ["Fire"] = 135810, ["Frost"] = 135846 };
SpecIcons["Warlock"] = { ["Affliction"] = 136145, ["Demonology"] = 236293, ["Destruction"] = 136186 };
SpecIcons["Monk"] = { ["Brewmaster"] = 608951, ["Mistweaver"] = 608952, ["Windwalker"] = 608953 };
SpecIcons["Druid"] = { ["Balance"] = 136096, ["Feral"] = 132115, ["Guardian"] = 132276, ["Restoration"] = 136041 };
SpecIcons["DemonHunter"] = { ["Havoc"] = 1247264, ["Vengeance"] = 1247265 };

function SC:OnInitialize()
	self.db = LibStub("AceDB-3.0"):New("SCDB", {
		profile = {
			minimap = {
				hide = false,
			}
		}
	});
	
	icon:Register("SCObj", SCLDB, self.db.profile.minimap);
	SC:RegisterChatCommand("specc", "SpecChangerCommand");
	NrOfSpecs = GetNumSpecializations();
end

function SC:SpecChangerCommand()
	self.db.profile.minimap.hide = not self.db.profile.minimap.hide;
	
	if self.db.profile.minimap.hide then
		icon:Hide("SCObj");
	else
		icon:Show("SCObj");
	end
end

function SCLDB:OnClick(button)

	if button == "LeftButton" then
		SC:OpenMenu();
	elseif button == "RightButton" then
		SC:OpenMenu();
	end
end

function GetCurrentSpec()
	local id, spec = GetSpecializationInfo(GetSpecialization());
	return spec;
end

function GetSpecByID(ID)
	return select(2, GetSpecializationInfo(ID));
end

function GetNumSpecs()
	return GetNumSpecializations();
end

function SC:SwitchSpec(ID)
	if ID ~= GetSpecialization() then
		SetSpecialization(ID);
		-- SCLDB.icon = select(4, GetSpecializationInfo(ID));
		SC:RegisterEvent("PLAYER_SPECIALIZATION_CHANGED");
	end
	
end

function SC:SaveSpec(ID)
	local icon = SpecIcons[UnitClass("Player")][GetSpecByID(ID)];
	SaveEquipmentSet(GetSpecByID(ID), icon);
end

-- Must wait for the spec change to complete before changing equipments
function SC:PLAYER_SPECIALIZATION_CHANGED()
	UseEquipmentSet(GetSpecByID(GetSpecialization()));
end

function SC:OpenMenu()
	local menu = { { text = "Specialization Changer", isTitle = true} };
	for i=1,GetNumSpecs() do
		local isChecked = false;
		
		if GetSpecialization() == i then
			isChecked = true;
		end
		
		table.insert(menu, { text = GetSpecByID(i), hasArrow = true, checked = isChecked,
			func = function() SC:SwitchSpec(i); end,
			menuList = {
				{ text = "Save", func = function() SC:SaveSpec(i); end }
			}
		});
	end
	table.insert(menu, { text = "Close", notCheckable = true } );
	
local menuFrame = CreateFrame("Frame", "SCMenuFrame", UIParent, "UIDropDownMenuTemplate")
EasyMenu(menu, menuFrame, "cursor", 0 , 0, "MENU");

end